re-frame-macros.core


->timecljmacro

(->time f)

Own time implementation - output information about the function and the time of its execution

Own time implementation - output information about the function and the time of its execution
raw docstring

->time->cljmacro

(->time-> arg f)

->time with arguments (for -> macro)

->time with arguments (for -> macro)
raw docstring

->time->>cljmacro

(->time->> f arg)

->time with arguments (for ->> macro)

->time with arguments (for ->> macro)
raw docstring

...cljmacro

(... & vars)

A macro that turns a list of variables into a map

A macro that turns a list of variables into a map
raw docstring

let-subcljmacro

(let-sub bindings & body)

reg-eventcljmacro

(reg-event name)

reg-event-debugcljmacro

(reg-event-debug name message)

reg-event-incljmacro

(reg-event-in name path)

reg-event-in-resetcljmacro

(reg-event-in-reset name path default-value)

reg-event-in-updatecljmacro

(reg-event-in-update name path first-value func)

reg-event-infocljmacro

(reg-event-info name message)

reg-event-mdcljmacro

(reg-event-md name middlewares)

reg-event-updatecljmacro

(reg-event-update name first-value func)

reg-subcljmacro

(reg-sub name default-value)

reg-sub-dcljmacro

(reg-sub-d domain name default-value)

reg-sub-eventcljmacro

(reg-sub-event name default-value)

reg-sub-event-dcljmacro

(reg-sub-event-d domain name default-value)

reg-sub-event-mdcljmacro

(reg-sub-event-md middlewares name default-value)

reg-sub-event-md-dcljmacro

(reg-sub-event-md-d middlewares domain name default-value)

reg-sub-incljmacro

(reg-sub-in name path default-value)

reg-sub-in-findcljmacro

(reg-sub-in-find name path find-fn)

reg-sub-in-mapcljmacro

(reg-sub-in-map name path map-fn)

reg-sub-in=cljmacro

(reg-sub-in= name path test-value)

reg-sub=cljmacro

(reg-sub= name test-value)

cljdoc builds & hosts documentation for Clojure/Script libraries